#!/bin/bash

# -----------------------------------------------------------------------------
# command line arguments
# -----------------------------------------------------------------------------

[[ $# -eq 3 ]] || {
  echo "usage: $(basename "$0") input_dir output_dir chunk_size" >&2
  exit 1
}

input_dir=$1
output_dir=$2
chunk_size=$3

[[ -d $input_dir ]] || {
  echo "$(basename "$0"): $input_dir does not exist" >&2
  exit 1
}

[[ $chunk_size -gt 0 ]] || {
  echo "$(basename "$0"): chunk size should be greater than 0" >&2
  exit 1
}

# -----------------------------------------------------------------------------
# create chunked dirs
# -----------------------------------------------------------------------------

current_chunk=1
current_element=1

find "$input_dir" -type f | while read -r file ; do
  if [[ $current_element -eq 1 ]] ; then
    chunk_dir="$output_dir/chunk-$current_chunk"
    mkdir -p "$chunk_dir"
  fi

  ln -t "$chunk_dir" "$file"

  if [[ $current_element -lt $chunk_size ]] ; then
    current_element=$(( current_element + 1 ))
  else
    current_element=1
    current_chunk=$(( current_chunk + 1 ))
  fi
done
